﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Data;

namespace RadMenu_MVVMExample
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }
    }

    public class StringToGeometryConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            GeometryIconModel gim = value as GeometryIconModel;
            if (value == null) return null;
            switch (gim.Type)
            {
                case GeometryType.Rectangle:
                    return new Rectangle() { Width = 16, Height = 16, Fill = new SolidColorBrush(gim.Color) };
                    break;
                case GeometryType.Ellipse:
                    return new Ellipse() { Width = 16, Height = 16, Fill = new SolidColorBrush(gim.Color) };
                    break;
                default:
                    break;
            }
            return null;
        }
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class MenuModel : ObservableCollection<ItemModel>
    {
        public MenuModel()
        {
            ItemModel item;

            item = new ItemModel() { Header = "File", Icon = new GeometryIconModel() { Color = Colors.Red, Type = GeometryType.Ellipse } };
            item.Items.Add(new ItemModel() { Header = "Open", Icon = new GeometryIconModel() { Color = Colors.Green, Type = GeometryType.Ellipse } });
            item.Items.Add(new ItemModel() { Header = "Save", Icon = new GeometryIconModel() { Color = Colors.Blue, Type = GeometryType.Rectangle } });
            item.Items.Add(new ItemModel() { Header = "Save as" });
            item.Items.Add(new ItemModel() { Header = "Close" });
            item.Items.Add(new ItemModel() { Header = "Exit" });
            this.Add(item);

            item = new ItemModel() { Header = "Edit", Icon = new GeometryIconModel() { Color = Colors.Blue, Type = GeometryType.Rectangle } };
            item.Items.Add(new ItemModel() { Header = "Cut", Icon = new GeometryIconModel() { Color = Colors.Purple, Type = GeometryType.Rectangle } });
            item.Items.Add(new ItemModel() { Header = "Copy", Icon = new GeometryIconModel() { Color = Colors.Cyan, Type = GeometryType.Rectangle } });
            item.Items.Add(new ItemModel() { Header = "Paste", Icon = new GeometryIconModel() { Color = Colors.Magenta, Type = GeometryType.Rectangle } });
            item.Items.Add(new ItemModel() { Header = "Delete", Icon = new GeometryIconModel() { Color = Colors.DarkGray, Type = GeometryType.Rectangle } });
            this.Add(item);

            item = new ItemModel() { Header = "View" };
            item.Items.Add(new ItemModel() { Header = "Code" });
            item.Items.Add(new ItemModel() { Header = "Design" });
            this.Add(item);

            item = new ItemModel() { Header = "Refactor" };
            item.Items.Add(new ItemModel() { Header = "Rename", Icon = new GeometryIconModel() { Color = Colors.Blue, Type = GeometryType.Rectangle } });
            item.Items.Add(new ItemModel() { Header = "Extract Method", Icon = new GeometryIconModel() { Color = Colors.Red, Type = GeometryType.Rectangle } });
            this.Add(item);

            item = new ItemModel() { Header = "Project" };
            item.Items.Add(new ItemModel() { Header = "Add Class", Icon = new GeometryIconModel() { Color = Colors.Blue, Type = GeometryType.Rectangle } });
            item.Items.Add(new ItemModel() { Header = "Add New Item", Icon = new GeometryIconModel() { Color = Colors.Red, Type = GeometryType.Rectangle } });
            item.Items.Add(new ItemModel() { Header = "Add Existing Item", Icon = new GeometryIconModel() { Color = Colors.Red, Type = GeometryType.Rectangle } });
            this.Add(item);
        }
    }

    public enum GeometryType { Rectangle, Ellipse }
    public class GeometryIconModel
    {
        public GeometryType Type { get; set; }
        public Color Color { get; set; }
    }

    public class ItemModel : INotifyPropertyChanged
    {
        public ItemModel()
        {
            _items = new ObservableCollection<ItemModel>();
        }

        private string _header;
        public string Header
        {
            get
            {
                return _header;
            }
            set
            {
                _header = value;
                OnNotifyPropertyChanged("Header");
            }
        }

        private GeometryIconModel _icon;
        public GeometryIconModel Icon
        {
            get
            {
                return _icon;
            }
            set
            {
                _icon = value;
                OnNotifyPropertyChanged("Icon");
            }
        }

        private ObservableCollection<ItemModel> _items;
        public ObservableCollection<ItemModel> Items { get { return _items; } }

        private void OnNotifyPropertyChanged(string property)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged.Invoke(this, new PropertyChangedEventArgs(property));
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }
}
